<?php
/*
Plugin Name:  LimaWeb WooCommerce Exclude Category
Plugin URI:   https://www.limaweb.nl/downloads/
 * Description: Verberg specifieke productcategorieën en hun producten van winkel- en collectiepagina's in WooCommerce.
Version:      1.0
Author:       LimaWeb
Author URI:   https://www.limaweb.nl/
License:      GPL2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class WC_Exclude_Category
{

    public function __construct()
    {
        add_action('admin_menu', array($this, 'create_settings_page'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('pre_get_posts', array($this, 'exclude_category_from_shop'));
    }

    // Creëer instellingenpagina
    public function create_settings_page()
    {
        add_options_page(
            'WooCommerce Exclude Category',
            'Categorie Uitsluiten',
            'manage_options',
            'wc-exclude-category',
            array($this, 'settings_page_content')
        );
    }

    // Registreer instellingen met veilige data-sanitatie
    public function register_settings()
    {
        register_setting('wc_exclude_category_options', 'wc_exclude_category_slugs', array(
            'sanitize_callback' => 'sanitize_text_field'
        ));
    }

    // Instellingen pagina content
    public function settings_page_content()
    {
        if (!current_user_can('manage_options')) {
            return;
        }

?>
        <div class="wrap">
            <h1><?php echo esc_html('WooCommerce Categorie Uitsluiten'); ?></h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('wc_exclude_category_options');
                do_settings_sections('wc_exclude_category_options');
                $option_value = get_option('wc_exclude_category_slugs');
                ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><?php echo esc_html('Categorie Slugs'); ?></th>
                        <td>
                            <input type="text" name="wc_exclude_category_slugs" value="<?php echo esc_attr($option_value); ?>" />
                            <p class="description"><?php echo esc_html('Voer de slugs van de categorieën in die je wilt uitsluiten, gescheiden door komma\'s.'); ?></p>
                        </td>
                    </tr>
                </table>
                <?php submit_button(); ?>
            </form>
        </div>
<?php
    }

    // Sluit categorieën uit van de winkelweergave
    public function exclude_category_from_shop($query)
    {
        if (!is_admin() && $query->is_main_query() && (is_shop() || is_product_category())) {
            $exclude_slugs = explode(',', get_option('wc_exclude_category_slugs', ''));
            $exclude_slugs = array_map('sanitize_title', array_map('trim', $exclude_slugs));

            if (!empty($exclude_slugs)) {
                $tax_query = $query->get('tax_query');
                if (!is_array($tax_query)) {
                    $tax_query = array();
                }
                $tax_query[] = array(
                    'taxonomy' => 'product_cat',
                    'field'    => 'slug',
                    'terms'    => $exclude_slugs,
                    'operator' => 'NOT IN',
                );
                $query->set('tax_query', $tax_query);
            }
        }
    }
}

new WC_Exclude_Category();
